#ifndef PANEL_COLOR_H
#define PANEL_COLOR_H

#include <gdk/gdk.h>

G_BEGIN_DECLS

void gtk_style_shade (GdkRGBA *a, GdkRGBA *b, gdouble k);

G_END_DECLS

#endif

